@@ -98,7 +98,12 @@ class GSPeerConnectionWatcher:
 
         @self.sio.event
         async def answer(id, description):
-            desc = type('new_dict', (object,), ast.literal_eval(description))
+
+            if isinstance(description, dict):
+                desc = description
+            else:
+                desc = type('new_dict', (object,), ast.literal_eval(description))
+
             await self.peerConnections.setRemoteDescription(desc)
 
         if "localhost" in self.gsdbs.credentials["signalserver"]:
